const Chance = require('chance')

const {
  user,
  handlingEditor,
  answerHE,
  noRecommendationHE,
} = require('./userData')

const {
  fragment,
  fragment1,
  noInvitesFragment,
  noInvitesFragment1,
  minorRevisionWithReview,
  majorRevisionWithReview,
  reviewCompletedFragment,
  minorRevisionWithoutReview,
  noEditorRecomedationFragment,
} = require('./fragments')

const {
  standardCollID,
  collectionNoInvitesID,
  twoVersionsCollectionId,
  minorRevisionCollectionID,
  majorRevisionCollectionID,
  collectionReviewCompletedID,
  oneReviewedFragmentCollectionID,
  noEditorRecomedationCollectionID,
  minorRevisionWithoutReviewCollectionID,
  majorRevisionWithoutReviewCollectionID,
} = require('./collectionIDs')

const chance = new Chance()
const collections = {
  collection: {
    id: standardCollID,
    delete: jest.fn(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [fragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection),
    getFragments: jest.fn(() => [fragment]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: false,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: answerHE.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
  collection1: {
    id: standardCollID,
    delete: jest.fn(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [fragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection),
    getFragments: jest.fn(() => [fragment]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: false,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: answerHE.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    customId: '1234568',
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
  },
  collection2: {
    id: collectionNoInvitesID,
    title: chance.sentence(),
    type: 'collection',
    fragments: [fragment1.id, noInvitesFragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection2),
    getFragments: jest.fn(() => [fragment1, noInvitesFragment]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: false,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: answerHE.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    customId: chance.natural({ min: 999999, max: 9999999 }),
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'pendingApproval',
  },
  collectionReviewCompleted: {
    id: collectionReviewCompletedID,
    delete: jest.fn(),
    type: 'collection',
    owners: [user.id],
    status: 'reviewCompleted',
    created: chance.timestamp(),
    customId: '0000001',
    fragments: [reviewCompletedFragment.id],
    getFragments: jest.fn(() => [reviewCompletedFragment]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        type: 'invitation',
        userId: handlingEditor.id,
        hasAnswer: true,
        invitedOn: chance.timestamp(),
        isAccepted: true,
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      name: handlingEditor.name,
      email: handlingEditor.email,
      hasAnswer: true,
      invitedOn: chance.timestamp(),
      isAccepted: true,
      respondedOn: chance.timestamp(),
    },
    technicalChecks: {},
  },
  twoVersionsCollection: {
    id: twoVersionsCollectionId,
    title: chance.sentence(),
    type: 'collection',
    fragments: [fragment.id, reviewCompletedFragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection),
    getFragments: jest.fn(() => [fragment, reviewCompletedFragment]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    status: 'revisionRequested',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
  noFragmentsCollection: {
    id: chance.guid(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [],
    owners: [user.id],
    save: jest.fn(() => collections.collection),
    getFragments: jest.fn(() => []),
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
  noEditorRecomedationCollection: {
    id: noEditorRecomedationCollectionID,
    title: chance.sentence(),
    type: 'collection',
    fragments: [noEditorRecomedationFragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.noEditorRecomedationCollection),
    getFragments: jest.fn(() => [noEditorRecomedationFragment]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: true,
        userId: noRecommendationHE.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: false,
        isAccepted: false,
        userId: answerHE.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: true,
      isAccepted: true,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: chance.timestamp(),
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    customId: chance.natural({ min: 999999, max: 9999999 }),
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
  },
  oneReviewedFragmentCollection: {
    id: oneReviewedFragmentCollectionID,
    title: chance.sentence(),
    type: 'collection',
    fragments: [reviewCompletedFragment.id, noInvitesFragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection),
    getFragments: jest.fn(() => [reviewCompletedFragment, noInvitesFragment]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    status: 'revisionRequested',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
  minorRevisionCollection: {
    id: minorRevisionCollectionID,
    delete: jest.fn(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [minorRevisionWithReview.id, noInvitesFragment1.id],
    owners: [user.id],
    save: jest.fn(() => collections.minorRevisionCollection),
    getFragments: jest.fn(() => [minorRevisionWithReview, noInvitesFragment1]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: true,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: true,
      isAccepted: true,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: chance.timestamp(),
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
  minorRevisionWithoutReviewCollection: {
    id: minorRevisionWithoutReviewCollectionID,
    delete: jest.fn(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [minorRevisionWithoutReview.id, noInvitesFragment1.id],
    owners: [user.id],
    save: jest.fn(() => collections.minorRevisionWithoutReviewCollection),
    getFragments: jest.fn(() => [
      minorRevisionWithoutReview,
      noInvitesFragment1,
    ]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: true,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: true,
      isAccepted: true,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: chance.timestamp(),
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
  majorRevisionCollection: {
    id: majorRevisionCollectionID,
    delete: jest.fn(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [majorRevisionWithReview.id, reviewCompletedFragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.minorRevisionCollection),
    getFragments: jest.fn(() => [
      majorRevisionWithReview,
      reviewCompletedFragment,
    ]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: true,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: true,
      isAccepted: true,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: chance.timestamp(),
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
  majorRevisionWithoutReviewCollection: {
    id: majorRevisionWithoutReviewCollectionID,
    delete: jest.fn(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [majorRevisionWithReview.id, noInvitesFragment1.id],
    owners: [user.id],
    save: jest.fn(() => collections.majorRevisionWithoutReviewCollection),
    getFragments: jest.fn(() => [majorRevisionWithReview, noInvitesFragment1]),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: true,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: true,
      isAccepted: true,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: chance.timestamp(),
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
}

module.exports = collections
